@@ -2,13 +2,32 @@
 #!/usr/bin/env python3
 # 加载文件
 import os
+import xlrd
+
 import yaml
 import json
 import csv
-from mobs.utils import exceptions
+from mobs.utils.takes import resolve_dict
+from mobs.utils.exceptions import FileFormatError, JSONDecodeError, CSVNotFound, FileNotFound, FileFormatNotSupported,FolderNotFound
+
+
+from typing import Tuple, Dict, Union, Text, List, Callable, Any, Mapping
+
+
+
+BASE_PATH = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+# 正则表达式匹配规则
+PATTERN_YML = os.path.join(BASE_PATH, 'config', 'pattern.yaml')
+#print(PATTERN_YML)
+
+class Config:
+
+    @staticmethod
+    @resolve_dict(name='pattern', key='zh_CN')
+    def get_yaml_conf(yaml_file=PATTERN_YML):
+        return FileUtils.load_file(yaml_file)
 
 
-from typing import Tuple, Dict, Union, Text, List, Callable
 
 class FileUtils(object):
 
@@ -25,10 +44,10 @@ class FileUtils(object):
         '''
         if not content:
             errMsg = u"File content is empty! \"{}\"".format(filePath) # 文件内容是空的！
-            raise exceptions.FileFormatError(errMsg)
+            raise FileFormatError(errMsg)
         elif not isinstance(content, (list, dict)):
             errMsg = u"File content format invalid!" # 文件内容格式无效！
-            raise  exceptions.FileFormatError(errMsg)
+            raise  FileFormatError(errMsg)
 
     @staticmethod
     def _load_text_file(filePath):
@@ -46,7 +65,8 @@ class FileUtils(object):
     @staticmethod
     def _load_yaml_file(filePath):
         with open(filePath, 'r', encoding='utf-8') as file_object:
-            yml_content = yaml.load(file_object)
+            yml_content = yaml.load(file_object, Loader=yaml.CLoader)
+            #yml_content = yaml.safe_load(file_object)
             FileUtils._check_format(filePath, yml_content)
             return yml_content
 
@@ -55,12 +75,13 @@ class FileUtils(object):
         with open(filePath, 'r', encoding='utf-8') as file_object:
             try:
                 json_content = json.load(file_object)
-            except exceptions.JSONDecodeError:
+            except JSONDecodeError:
                 errMsg = u"JsonDecodeError:Json file format error! \"{}\"".format(filePath)
-                raise exceptions.FileFormatError(errMsg)
+                raise FileFormatError(errMsg)
             FileUtils._check_format(filePath, json_content)
             return json_content
 
+
     @staticmethod
     def _load_csv_file(filePath):
         csv_content = []
@@ -72,8 +93,9 @@ class FileUtils(object):
 
     @staticmethod
     def load_file(filePath):
+
         if not os.path.isfile(filePath):
-            raise exceptions.FileNotFound(u"File is not exist \"{}\"".format(filePath))
+            raise FileNotFound(u"File is not exist \"{}\"".format(filePath))
         file_suffix = os.path.splitext(filePath)[1].lower()
         if file_suffix == '.txt':
             return FileUtils._load_text_file(filePath)
@@ -87,7 +109,7 @@ class FileUtils(object):
             # 其它文件后缀
             errMsg = u"File format not supported \"{}\"".format(filePath)
 
-            raise exceptions.FileFormatNotSupported(errMsg)
+            raise FileFormatNotSupported(errMsg)
 
     @staticmethod
     def load_folder_files(folderPath: Text, recursive: bool = True) -> List:
@@ -98,7 +120,7 @@ class FileUtils(object):
         :return: file_list >>> 文件路径 ; fileList>>> 文件名
         '''
         if not os.path.isdir(folderPath):
-            raise exceptions.FolderNotFound(u"Folder does not exist \"{}\"".format(folderPath))
+            raise FolderNotFound(u"Folder does not exist \"{}\"".format(folderPath))
 
         if isinstance(folderPath, (list, set)):
             files = []
@@ -106,7 +128,7 @@ class FileUtils(object):
                 files.extend(FileUtils.load_folder_files(path, recursive))
             return files
         if not os.path.exists(folderPath):
-            raise exceptions.FolderNotFound(u"Folder does not exist \"{}\"".format(folderPath))
+            raise FolderNotFound(u"Folder does not exist \"{}\"".format(folderPath))
         file_list = []
         #fileList = []
         for dirPath, dirNames, fileNames in os.walk(folderPath):
@@ -176,11 +198,11 @@ class FileUtils(object):
         return result
 
 class ReadExcel:
-    import xlrd
+
     def __init__(self,excel_file):
         if not os.path.isfile(excel_file):
             # file path not exist
-            raise exceptions.CSVNotFound(excel_file)
+            raise CSVNotFound(excel_file)
         self.workbook = xlrd.open_workbook(excel_file)
 
     def get_all_sheetnames(self):
@@ -354,7 +376,7 @@ class ReadExcel:
         return self.col
 
 if __name__ == '__main__':
-    path = r"D:\CodeBase\mobs\test\test_data\test_01.txt"
-    a = FileUtils()
-    data = a.load_file_name(path)
-    print(data)
\ No newline at end of file
+    conf = Config()
+    te = FileUtils.load_file('D:\CodeBase\mobslala\mobs\config\pattern.yaml')
+
+    print(conf.get_yaml_conf())
